IntRange extension

on

Methods

inRange(int min, int max, {bool inclusive = true}) bool

Available on int, provided by the IntRange extension

Checks if this integer is in the specified range.
to(int end, {int step = 1}) List<int>

Available on int, provided by the IntRange extension

Creates a list of integers from this value to end (inclusive).
until(int end, {int step = 1}) List<int>

Available on int, provided by the IntRange extension

Creates a list of integers from this value to end (exclusive).